pub struct AdjustInput {
pub sku: String,
pub location_id: String,
pub new_quantity: f64,
pub reason: String,
pub actor: String,
}Fields
sku: Stringlocation_id: Stringnew_quantity: f64reason: Stringactor: StringTrait Implementations
Sourceimpl Debug for AdjustInput
impl Debug for AdjustInput
Sourceimpl<'de> Deserialize<'de> for AdjustInput
impl<'de> Deserialize<'de> for AdjustInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdjustInput
impl JsonSchema for AdjustInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdjustInput
impl RefUnwindSafe for AdjustInput
impl Send for AdjustInput
impl Sync for AdjustInput
impl Unpin for AdjustInput
impl UnsafeUnpin for AdjustInput
impl UnwindSafe for AdjustInput