pub struct BomCheckInput {
pub parent_sku: String,
pub quantity: f64,
pub location_id: String,
}Fields
parent_sku: Stringquantity: f64location_id: StringTrait Implementations
Sourceimpl Debug for BomCheckInput
impl Debug for BomCheckInput
Sourceimpl<'de> Deserialize<'de> for BomCheckInput
impl<'de> Deserialize<'de> for BomCheckInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BomCheckInput
impl JsonSchema for BomCheckInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BomCheckInput
impl RefUnwindSafe for BomCheckInput
impl Send for BomCheckInput
impl Sync for BomCheckInput
impl Unpin for BomCheckInput
impl UnsafeUnpin for BomCheckInput
impl UnwindSafe for BomCheckInput