pub struct BomInput {
pub parent_sku: String,
pub components: Vec<Value>,
}Fields
parent_sku: Stringcomponents: Vec<Value>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for BomInput
impl<'de> Deserialize<'de> for BomInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BomInput
impl JsonSchema for BomInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BomInput
impl RefUnwindSafe for BomInput
impl Send for BomInput
impl Sync for BomInput
impl Unpin for BomInput
impl UnsafeUnpin for BomInput
impl UnwindSafe for BomInput