pub struct IssueInput {
pub sku: String,
pub quantity: f64,
pub location_id: String,
pub reference: Option<String>,
pub actor: String,
}Fields
sku: Stringquantity: f64location_id: Stringreference: Option<String>actor: StringTrait Implementations
Sourceimpl Debug for IssueInput
impl Debug for IssueInput
Sourceimpl<'de> Deserialize<'de> for IssueInput
impl<'de> Deserialize<'de> for IssueInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IssueInput
impl JsonSchema for IssueInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for IssueInput
impl RefUnwindSafe for IssueInput
impl Send for IssueInput
impl Sync for IssueInput
impl Unpin for IssueInput
impl UnsafeUnpin for IssueInput
impl UnwindSafe for IssueInput