pub struct ItemInput {
pub sku: String,
pub name: String,
pub category: String,
pub unit: Option<String>,
pub reorder_point: Option<f64>,
pub reorder_qty: Option<f64>,
pub cost: Option<f64>,
pub currency: Option<String>,
}Fields
sku: Stringname: Stringcategory: Stringunit: Option<String>reorder_point: Option<f64>reorder_qty: Option<f64>cost: Option<f64>currency: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ItemInput
impl<'de> Deserialize<'de> for ItemInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ItemInput
impl JsonSchema for ItemInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ItemInput
impl RefUnwindSafe for ItemInput
impl Send for ItemInput
impl Sync for ItemInput
impl Unpin for ItemInput
impl UnsafeUnpin for ItemInput
impl UnwindSafe for ItemInput