pub struct ReserveInput {
pub sku: String,
pub location_id: String,
pub quantity: f64,
pub reference: String,
pub expires_hours: Option<u32>,
}Fields
sku: Stringlocation_id: Stringquantity: f64reference: Stringexpires_hours: Option<u32>Trait Implementations
Sourceimpl Debug for ReserveInput
impl Debug for ReserveInput
Sourceimpl<'de> Deserialize<'de> for ReserveInput
impl<'de> Deserialize<'de> for ReserveInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReserveInput
impl JsonSchema for ReserveInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReserveInput
impl RefUnwindSafe for ReserveInput
impl Send for ReserveInput
impl Sync for ReserveInput
impl Unpin for ReserveInput
impl UnsafeUnpin for ReserveInput
impl UnwindSafe for ReserveInput