pub struct StockQuery {
pub sku: String,
pub location_id: Option<String>,
}Fields
sku: Stringlocation_id: Option<String>Trait Implementations
Sourceimpl Debug for StockQuery
impl Debug for StockQuery
Sourceimpl<'de> Deserialize<'de> for StockQuery
impl<'de> Deserialize<'de> for StockQuery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StockQuery
impl JsonSchema for StockQuery
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StockQuery
impl RefUnwindSafe for StockQuery
impl Send for StockQuery
impl Sync for StockQuery
impl Unpin for StockQuery
impl UnsafeUnpin for StockQuery
impl UnwindSafe for StockQuery