pub struct TransferInput {
pub sku: String,
pub quantity: f64,
pub from_location: String,
pub to_location: String,
pub actor: String,
}Fields
sku: Stringquantity: f64from_location: Stringto_location: Stringactor: StringTrait Implementations
Sourceimpl Debug for TransferInput
impl Debug for TransferInput
Sourceimpl<'de> Deserialize<'de> for TransferInput
impl<'de> Deserialize<'de> for TransferInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TransferInput
impl JsonSchema for TransferInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TransferInput
impl RefUnwindSafe for TransferInput
impl Send for TransferInput
impl Sync for TransferInput
impl Unpin for TransferInput
impl UnsafeUnpin for TransferInput
impl UnwindSafe for TransferInput