pub struct WaveIdInput {
pub wave_id: String,
}Fields
wave_id: StringTrait Implementations
Sourceimpl Debug for WaveIdInput
impl Debug for WaveIdInput
Sourceimpl<'de> Deserialize<'de> for WaveIdInput
impl<'de> Deserialize<'de> for WaveIdInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WaveIdInput
impl JsonSchema for WaveIdInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WaveIdInput
impl RefUnwindSafe for WaveIdInput
impl Send for WaveIdInput
impl Sync for WaveIdInput
impl Unpin for WaveIdInput
impl UnsafeUnpin for WaveIdInput
impl UnwindSafe for WaveIdInput